# What's new

## 1.0.2 (11/04/2025)
- Rename Round Robin turn manager
- Fix bug where Round Robin would crash when used by a DiscussionExperiment
- Updated dev environments

## 1.0.1 (09/04/2025)

- Fix issue with online documentation not showing modules
- Include pytorch as default transformers engine
- Update conda environments